@@ -7,10 +7,17 @@ github_install <- function(gitrepo, gituser, gitbranch = "master"){
   gittmpdir <- tempfile("githubdir");
   stopifnot(dir.create(gittmpdir));
   
-  #NOTE: for now we can't capture output from install_github
-  #Dependencies = TRUE otherwise it will skip currently loaded packages leading to problems.
+  #For private repos
+  mysecret <- gitsecret();
+  if(length(mysecret) && length(mysecret$auth_token) && nchar(mysecret$auth_token)){
+    auth = paste0(", auth_user=", deparse(mysecret$auth_token), ", password=\"x-oauth-basic\"")
+  } else {
+    auth = "";
+  }
+  
+  #Dependencies = TRUE would also install currently loaded packages.
   inlib(gittmpdir, {
-    output <- try_rscript(paste0("library(methods);library(devtools);install_github(", deparse(gitrepo), ",", deparse(gituser), ",", deparse(gitbranch), ", quick=TRUE, args='--library=", deparse(gittmpdir), "')"));
+    output <- try_rscript(paste0("library(methods);library(devtools);install_github(", deparse(gitrepo), ",", deparse(gituser), ",", deparse(gitbranch), auth, ", quick=TRUE, args='--library=", deparse(gittmpdir), "')"));
   });  
   
   #We require package name with identical repo name
